==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/OdplatnoscDoliczeniePobyt.java <==
package pl.topteam.dps.model.main_gen;

import java.math.BigDecimal;
import pl.topteam.dps.enums.StatusDoliczeniePobyt;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class OdplatnoscDoliczeniePobyt extends GenericDPSObject {
    /**
     * ODPLATNOSC_DOLICZENIE_POBYT.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * ODPLATNOSC_DOLICZENIE_POBYT.ZADLUZENIE_POZYCJA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long zadluzeniePozycjaId;

    /**
     * ODPLATNOSC_DOLICZENIE_POBYT.KWOTA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private BigDecimal kwota;

    /**
     * ODPLATNOSC_DOLICZENIE_POBYT.STATUS
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private StatusDoliczeniePobyt status;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return ODPLATNOSC_DOLICZENIE_POBYT.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * ODPLATNOSC_DOLICZENIE_POBYT.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return ODPLATNOSC_DOLICZENIE_POBYT.ZADLUZENIE_POZYCJA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getZadluzeniePozycjaId() {
        return zadluzeniePozycjaId;
    }

    /**
     * ODPLATNOSC_DOLICZENIE_POBYT.ZADLUZENIE_POZYCJA_ID
     *
     * @param zadluzeniePozycjaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setZadluzeniePozycjaId(Long zadluzeniePozycjaId) {
        this.zadluzeniePozycjaId = zadluzeniePozycjaId;
    }

    /**
     * @return ODPLATNOSC_DOLICZENIE_POBYT.KWOTA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public BigDecimal getKwota() {
        return kwota;
    }

    /**
     * ODPLATNOSC_DOLICZENIE_POBYT.KWOTA
     *
     * @param kwota
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKwota(BigDecimal kwota) {
        this.kwota = kwota;
    }

    /**
     * @return ODPLATNOSC_DOLICZENIE_POBYT.STATUS
     * @mbggenerated 2014-03-10 10:45:37
     */
    public StatusDoliczeniePobyt getStatus() {
        return status;
    }

    /**
     * ODPLATNOSC_DOLICZENIE_POBYT.STATUS
     *
     * @param status
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setStatus(StatusDoliczeniePobyt status) {
        this.status = status;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        OdplatnoscDoliczeniePobyt other = (OdplatnoscDoliczeniePobyt) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getZadluzeniePozycjaId() == null ? other.getZadluzeniePozycjaId() == null : this.getZadluzeniePozycjaId().equals(other.getZadluzeniePozycjaId()))
            && (this.getKwota() == null ? other.getKwota() == null : this.getKwota().equals(other.getKwota()))
            && (this.getStatus() == null ? other.getStatus() == null : this.getStatus().equals(other.getStatus()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getZadluzeniePozycjaId() == null) ? 0 : getZadluzeniePozycjaId().hashCode());
        result = prime * result + ((getKwota() == null) ? 0 : getKwota().hashCode());
        result = prime * result + ((getStatus() == null) ? 0 : getStatus().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", zadluzeniePozycjaId=").append(zadluzeniePozycjaId);
        sb.append(", kwota=").append(kwota);
        sb.append(", status=").append(status);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/OdplatnoscDoliczeniePobyt.java <==
package pl.topteam.dps.model.main_gen;

import java.math.BigDecimal;
import pl.topteam.dps.enums.StatusDoliczeniePobyt;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class OdplatnoscDoliczeniePobyt extends GenericDPSObject {
    /**
     * ODPLATNOSC_DOLICZENIE_POBYT.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * ODPLATNOSC_DOLICZENIE_POBYT.ZADLUZENIE_POZYCJA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long zadluzeniePozycjaId;

    /**
     * ODPLATNOSC_DOLICZENIE_POBYT.KWOTA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private BigDecimal kwota;

    /**
     * ODPLATNOSC_DOLICZENIE_POBYT.STATUS
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private StatusDoliczeniePobyt status;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return ODPLATNOSC_DOLICZENIE_POBYT.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * ODPLATNOSC_DOLICZENIE_POBYT.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return ODPLATNOSC_DOLICZENIE_POBYT.ZADLUZENIE_POZYCJA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getZadluzeniePozycjaId() {
        return zadluzeniePozycjaId;
    }

    /**
     * ODPLATNOSC_DOLICZENIE_POBYT.ZADLUZENIE_POZYCJA_ID
     *
     * @param zadluzeniePozycjaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setZadluzeniePozycjaId(Long zadluzeniePozycjaId) {
        this.zadluzeniePozycjaId = zadluzeniePozycjaId;
    }

    /**
     * @return ODPLATNOSC_DOLICZENIE_POBYT.KWOTA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public BigDecimal getKwota() {
        return kwota;
    }

    /**
     * ODPLATNOSC_DOLICZENIE_POBYT.KWOTA
     *
     * @param kwota
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKwota(BigDecimal kwota) {
        this.kwota = kwota;
    }

    /**
     * @return ODPLATNOSC_DOLICZENIE_POBYT.STATUS
     * @mbggenerated 2014-03-13 16:02:38
     */
    public StatusDoliczeniePobyt getStatus() {
        return status;
    }

    /**
     * ODPLATNOSC_DOLICZENIE_POBYT.STATUS
     *
     * @param status
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setStatus(StatusDoliczeniePobyt status) {
        this.status = status;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        OdplatnoscDoliczeniePobyt other = (OdplatnoscDoliczeniePobyt) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getZadluzeniePozycjaId() == null ? other.getZadluzeniePozycjaId() == null : this.getZadluzeniePozycjaId().equals(other.getZadluzeniePozycjaId()))
            && (this.getKwota() == null ? other.getKwota() == null : this.getKwota().equals(other.getKwota()))
            && (this.getStatus() == null ? other.getStatus() == null : this.getStatus().equals(other.getStatus()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getZadluzeniePozycjaId() == null) ? 0 : getZadluzeniePozycjaId().hashCode());
        result = prime * result + ((getKwota() == null) ? 0 : getKwota().hashCode());
        result = prime * result + ((getStatus() == null) ? 0 : getStatus().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", zadluzeniePozycjaId=").append(zadluzeniePozycjaId);
        sb.append(", kwota=").append(kwota);
        sb.append(", status=").append(status);
        sb.append("]");
        return sb.toString();
    }
}
